aboutsummaryrefslogtreecommitdiffstats
path: root/lib/private
diff options
context:
space:
mode:
authorThomas Müller <thomas.mueller@tmit.eu>2014-08-04 11:03:50 +0200
committerThomas Müller <thomas.mueller@tmit.eu>2014-08-04 11:03:50 +0200
commit65903a012a05d012b463d944594afa0104386426 (patch)
treeebbf8c8442e6f78ff11ebad4bebcdd4fe9f426b2 /lib/private
parent5a2952e2eb8f65ec6239375c10723da7151a1116 (diff)
parent7a07690b250e799474fdbc73ace4ead5c2906b75 (diff)
downloadnextcloud-server-65903a012a05d012b463d944594afa0104386426.tar.gz
nextcloud-server-65903a012a05d012b463d944594afa0104386426.zip
Merge pull request #10025 from owncloud/l10n-typo
typo fix from transifex suggestion
Diffstat (limited to 'lib/private')
-rw-r--r--lib/private/share/share.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/private/share/share.php b/lib/private/share/share.php
index 7fd5cd70e1d..450c71cf8a2 100644
--- a/lib/private/share/share.php
+++ b/lib/private/share/share.php
@@ -926,7 +926,7 @@ class Share extends \OC\Share\Constants {
}
/**
* validate expire date if it meets all constraints
*
* @param string $expireDate well formate date string, e.g. "DD-MM-YYYY"
* @param string $shareTime timestamp when the file was shared
@@ -956,16 +956,16 @@ class Share extends \OC\Share\Constants {
$maxDays = \OCP\Config::getAppValue('core', 'shareapi_expire_after_n_days', '7');
$maxDate->add(new \DateInterval('P' . $maxDays . 'D'));
if ($date > $maxDate) {
- $warning = 'Can not set expire date. Shares can not expire later then ' . $maxDays . ' after they where shared';
- $warning_t = $l->t('Can not set expire date. Shares can not expire later then %s after they where shared', array($maxDays));
+ $warning = 'Cannot set expiration date. Shares cannot expire later than ' . $maxDays . ' after they where shared';
+ $warning_t = $l->t('Cannot set expiration date. Shares cannot expire later than %s after they where shared', array($maxDays));
\OCP\Util::writeLog('OCP\Share', $warning, \OCP\Util::WARN);
throw new \Exception($warning_t);
}
}
if ($date < $today) {
- $message = 'Can not set expire date. Expire date is in the past';
- $message_t = $l->t('Can not set expire date. Expire date is in the past');
+ $message = 'Cannot set expiration date. Expiration date is in the past';
+ $message_t = $l->t('Cannot set expiration date. Expiration date is in the past');
\OCP\Util::writeLog('OCP\Share', $message, \OCP\Util::WARN);
throw new \Exception($message_t);
}
@@ -1018,10 +1018,10 @@ class Share extends \OC\Share\Constants {
$result = false;
// only use default expire date for link shares
if ((int) $item['share_type'] === self::SHARE_TYPE_LINK) {
// calculate expire date
if (!empty($item['expiration'])) {
$userDefinedExpire = new \DateTime($item['expiration']);
$expires = $userDefinedExpire->getTimestamp();
@@ -1030,7 +1030,7 @@ class Share extends \OC\Share\Constants {
}
// get default expire settings
$defaultSettings = Helper::getDefaultExpireSetting();
$expires = Helper::calculateExpireDate($defaultSettings, $item['stime'], $expires);
@@ -926,7 +926,7 @@ class Share extends \OC\Share\Constants {
}
/**
- * validate expire date if it meets all constraints
+ * validate expiration date if it meets all constraints
*
* @param string $expireDate well formate date string, e.g. "DD-MM-YYYY"
@@ -1018,10 +1018,10 @@ class Share extends \OC\Share\Constants {
$result = false;
- // only use default expire date for link shares
+ // only use default expiration date for link shares
if ((int) $item['share_type'] === self::SHARE_TYPE_LINK) {
@@ -1018,10 +1018,10 @@ class Share extends \OC\Share\Constants {
if ((int) $item['share_type'] === self::SHARE_TYPE_LINK) {
- // calculate expire date
+ // calculate expiration date
if (!empty($item['expiration'])) {
$userDefinedExpire = new \DateTime($item['expiration']);
@@ -1030,7 +1030,7 @@ class Share extends \OC\Share\Constants {
}
- // get default expire settings
+ // get default expiration settings
$defaultSettings = Helper::getDefaultExpireSetting();
$expires = Helper::calculateExpireDate($defaultSettings, $item['stime'], $expires);